@@ -267,7 +267,7 @@ $public/$error_code.html if it exists.
 
 =head2 auto_reload (boolean)
 
-Requires L<Module::Refresh>.
+Requires L<Module::Refresh> and L<Clone>.
 
 If set to true, Dancer will reload the route handlers whenever the file where
 they are defined is changed. This is very useful in development environment but
