@@ -9,6 +9,7 @@ use Getopt::Long;
 my $options = {
     port        => setting('port'),
     daemon      => setting('daemon'),
+    confdir     => setting('confdir') || setting('appdir'),
     environment => 'development',
 };
 
@@ -24,6 +25,7 @@ sub process_args {
         'port=i'        => sub { arg_to_setting(@_) },
         'daemon'        => sub { arg_to_setting(@_) },
         'environment=s' => sub { arg_to_setting(@_) },
+        'confdir=s'     => sub { arg_to_setting(@_) },
     ) || usage_and_exit();
 
     usage_and_exit() if $help;
@@ -38,6 +40,7 @@ sub print_usage {
  Options:
    --daemon             Run in background (false)
    --port=XXXX          Port number to bind to (3000)
+   --confdir=PATH       Path the config dir (appdir if not specified)
    --environment=ENV    Environement to use (development)
    --help               Display usage information
 
@@ -54,6 +57,17 @@ during the development phase.
 This lets you change the port number to use when running the process. By
 default, the port 3000 will be used.
 
+--confdir=PATH
+
+By default, Dancer looks in the appdir for config files (config.yml and
+environments files). You can change this with specifying an alternate path to
+the configdir option.
+
+Dancer will then look in that directory for a file config.yml and the
+appropriate environement configuration file.
+
+If not specified, confdir points to appdir.
+
 --environment=ENV
 
 THIS OPTIONS IS NOT SUPPORTED YET 
