@@ -18,8 +18,9 @@ sub _should {
     my ($self, $msg_level) = @_;
     my $conf_level = setting('log') || 'debug';
     my $levels = {
+
         # levels < 0 are for core only
-        core    => -10, 
+        core => -10,
 
         # levels > 0 are for end-users only
         debug   => 1,
@@ -35,23 +36,26 @@ sub format_message {
 
     $level = 'warn' if $level eq 'warning';
     $level = sprintf('%5s', $level);
-    
-    my ($package, $file, $line) = caller(4);
+
+    my ($package, $file, $line) = caller(3);
     $package ||= '-';
     $file    ||= '-';
     $line    ||= '-';
 
     my $time = Dancer::SharedData->timer->tick;
-    my $r = Dancer::SharedData->request;
+    my $r    = Dancer::SharedData->request;
     if (defined $r) {
-        return "[$$] $level \@$time> [hit #".$r->id."] $message in $file l. $line\n";
+        return
+            "[$$] $level \@$time> [hit #"
+          . $r->id
+          . "] $message in $file l. $line\n";
     }
     else {
         return "[$$] $level \@$time> $message in $file l. $line\n";
     }
 }
 
-sub core    { $_[0]->_should('core')    and $_[0]->_log('core' ,   $_[1]) }
+sub core    { $_[0]->_should('core')    and $_[0]->_log('core',    $_[1]) }
 sub debug   { $_[0]->_should('debug')   and $_[0]->_log('debug',   $_[1]) }
 sub warning { $_[0]->_should('warning') and $_[0]->_log('warning', $_[1]) }
 sub error   { $_[0]->_should('error')   and $_[0]->_log('error',   $_[1]) }
