@@ -21,27 +21,29 @@ sub init {
     if (!-d $logdir) {
         if (not mkdir $logdir) {
             warn "log directory $logdir doesn't exist, unable to create";
-            return undef $logfile;
+            undef $logfile;
+            return;
         }
     }
 
     $logfile = setting('environment');
     $logfile = path($logdir, "$logfile.log");
 
-    unless (open(LOGFILE, '>>', $logfile)) {
+    my $fh;
+    unless (open($fh, '>>', $logfile)) {
         warn "Unable to open $logfile for writing, unable to log";
         undef $logfile;
     }
-    close LOGFILE;
+    close $fh;
 }
 
 sub _log {
     my ($self, $level, $message) = @_;
     return unless defined $logfile;
 
-    if (open(LOGFILE, '>>', $logfile)) {
-        print LOGFILE $self->format_message($level => $message);
-        close LOGFILE;
+    if (open(my $fh, '>>', $logfile)) {
+        print $fh $self->format_message($level => $message);
+        close $fh;
     }
 }
 
