@@ -16,6 +16,10 @@ use Dancer::SharedData;
 use Dancer::Logger;
 use MIME::Types;
 
+BEGIN {
+	MIME::Types->new(only_complete => 1);
+};
+
 sub render_file {
     return get_file_response();
 }
@@ -186,22 +190,21 @@ sub get_mime_type {
 # set of builtin templates needed by Dancer when rendering HTML pages
 sub templates {
     my $charset = setting('charset') || 'UTF-8';
-    {   default => '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
-        "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<html>
+    {   default => '<!DOCTYPE html>
+<html lang="en-US">
 <head>
 <title><% title %></title>
 <link rel="stylesheet" href="/css/<% style %>.css" />
-<meta http-equiv="Content-type" content="text/html; charset='.$charset.'" />
+<meta charset=' . $charset . '" />
 </head>
 <body>
 <h1><% title %></h1>
 <div id="content">
 <% content %>
 </div>
-<div id="footer">
+<footer>
 Powered by <a href="http://perldancer.org/">Dancer</a> <% version %>
-</div>
+</footer>
 </body>
 </html>',
     };
