@@ -34,11 +34,28 @@ sub current {
 }
 
 # helpers for the route handlers
+sub exists { defined $CURRENT && length($CURRENT->{content}) }
 sub set          { $CURRENT                 = shift; }
 sub status       { $CURRENT->{status}       = Dancer::HTTP->status(shift) }
 sub content_type { $CURRENT->{content_type} = shift }
 sub pass         { $CURRENT->{pass}         = 1 }
 
+sub halt {
+    my ($class, $content) = @_;
+
+    if (ref($content) && ref($content) eq 'Dancer::Response') {
+        $CURRENT = $content;
+    }
+    else {
+        $CURRENT = Dancer::Response->new;
+        $CURRENT->{content} = $content;
+    }
+    $CURRENT->{halted} = 1;
+    return $content;
+}
+
+sub halted { $CURRENT && $CURRENT->{halted} }
+
 sub headers {
     push @{$CURRENT->{headers}}, @_;
     $CURRENT->sanitize_headers;
@@ -68,7 +85,8 @@ sub update_headers {
 
     for (my $i = 0; $i < scalar(@$headers); $i += 2) {
         my ($key, $value) = ($headers->[$i], $headers->[$i + 1]);
-        push @new_headers, ($key => $params{$key}) if exists($params{$key});
+        my $header_value = (exists $params{$key}) ? $params{$key} : $value;
+        push @new_headers, ($key => $header_value);
     }
     $self->{headers} = \@new_headers;
 }
