@@ -4,6 +4,7 @@ use warnings;
 
 use base 'Dancer::Engine';
 
+use Dancer::Config 'setting';
 use Dancer::Cookies;
 use File::Spec;
 
@@ -52,8 +53,14 @@ sub new {
     return $self;
 }
 
-# it's a constant, maybe a setting in the future
-my $SESSION_NAME = 'dancer.session';
+# session name can be set in configuration file:
+# setting session_name => 'mydancer.session';
+my $SESSION_NAME = session_name();
+
+# this method can be overwrite in any Dancer::Session::* module
+sub session_name {
+    setting('session_name') || 'dancer.session';
+}
 
 # we try to make the best random number
 # with native Perl 5 code.
@@ -81,12 +88,16 @@ sub read_session_id {
 
 sub write_session_id {
     my ($class, $id) = @_;
-    Dancer::Cookies->cookies->{$SESSION_NAME} = Dancer::Cookie->new(
+    my %cookie = (
         name  => $SESSION_NAME,
-        value => $id,
-
-        # no expires: will expire when the browser is closed
+        value => $id
     );
+    if (my $expires = setting('session_expires')) {
+        $cookie{expires} =
+          Dancer::Cookie::_epoch_to_gmtstring(time + $expires);
+    }
+
+    Dancer::Cookies->cookies->{$SESSION_NAME} = Dancer::Cookie->new(%cookie);
 }
 
 1;
@@ -96,7 +107,7 @@ __END__
 
 =head1 NAME
 
-Dancer::Session::Abstract - Abstract class for session engine
+Dancer::Session::Abstract - abstract class for session engine
 
 =head1 SPEC
 
@@ -110,7 +121,7 @@ needed to manipulate a session, whatever its storing engine is.
 =item B<id>
 
 The session id will be written to a cookie, named C<dancer.session>, it is
-assumed that a client must accept cookies to be able to use a session-aware 
+assumed that a client must accept cookies to be able to use a session-aware
 Dancer webapp.
 
 =item B<storage engine>
@@ -137,9 +148,13 @@ done in order to allow multiple session storage with a common interface.
 Any session engine must inherits from Dancer::Session::Abstract and implement
 the following abstract methods.
 
-=head2 Abstract Methods 
+The default session name is "dancer_session". This can be set in your config file:
 
-=over 4 
+    setting session_name: "mydancer_session"
+
+=head2 Abstract Methods
+
+=over 4
 
 =item B<retrieve($id)>
 
@@ -158,6 +173,10 @@ Write the session object to the storage engine.
 
 Remove the current session object from the storage engine.
 
+=item B<session_name> (optional)
+
+Returns a string with the name of cookie used for storing the session ID.
+
 =back
 
 =head2 Inherited Methods
@@ -169,7 +188,7 @@ should be OK for each session engine.
 
 =item B<build_id>
 
-Build a new uniq id. 
+Build a new uniq id.
 
 =item B<read_session_id>
 
